<?php
namespace Drupal\ip_ban;

/**
 * Base class for common test configuration.
 */
class IPBanTestBase extends DrupalWebTestCase {

  protected $adminSitesUser;
  protected $ipBanType;

  /**
   * Implement setUp().
   */
  public function setUp() {
    // ip2country is required by ip_ban, and therefore needed for some of the
    // unit and functional testing.
    parent::setUp(array('ip_ban', 'ip2country'));
    // Add a content type to create dummy page for testing valid paths and
    // proper redirects.
    $this->ipBanType = $this->drupalCreateContentType(array(
      'name' => 'IP Ban Node',
      'type' => 'ipban_node',
    ));
    // Create and log in our privileged user.
    $this->adminSitesUser = $this->drupalCreateUser(array(
      'administer site configuration',
      'create ipban_node content',
      'edit any ipban_node content',
      'access content',
      'bypass node access',
      'administer blocks',
      // The admin must have this permission to avoid immediately losing access
      // when using a spoofed IP address.
      'ignore ip_ban',
    ));
  }

  /**
   * Add a node of type ipban-node for path and other testing.
   */
  public function addBanNode($title = '') {
    if (empty($title)) {
      $title = $this->randomName();
    }
    $edit = array(
      'title' => $title,
    );
    $this->drupalPost('node/add/ipban-node', $edit, t('Save'));
    $this->assertText('IP Ban Node ' . $edit['title'] . ' has been created', 'Found node creation message');
  }

}
